import xarray as xr
from glob import glob
import pyrams.xarray
from pyrams.data_tools import domain_mean_netcdf
import os

import argparse
parser = argparse.ArgumentParser()
parser.add_argument('path', type=str, help='Path to h5 files')
parser.add_argument('outfile', type=str, help='Path and name of Netcdf4 file to generate')
parser.add_argument('--parallel', action='store_true', help='Run in parallel with Dask')

args = vars(parser.parse_args())

fpath = args['path']
outfile = args['outfile']
parallel = args['parallel']
print(f"Reading files from {fpath}")
print(f"Writing to {outfile}")

# user = os.environ['USER']
# jobid = os.environ['SLURM_JOB_ID']
# scratch = f'/scratch/{user}/{jobid}/'


if __name__ == '__main__':
    # print(f"Making directory {scratch}")
    # os.makedirs(scratch, exist_ok=True)

    flist = sorted(glob(fpath + '/*.h5'))
    print("Opening dataset")
    ds = xr.open_mfdataset(flist, combine='nested', concat_dim='time')
    ds = ds.rams.fix_dims(flist=flist, dx=62.5, dz=6.25)

    print("Writing to disk")
    ww = ds.WC**2
    ww.name = "VFLXW"

    u_prime = ds.UC - ds.UC.mean()
    v_prime = ds.VC - ds.VC.mean()

    tke = 0.5 * (ww + u_prime + v_prime)
    tke.name = 'TKE'

    theta_prime = ds.THETA - ds.THETA.mean()
    theta_w = ds.WC * theta_prime
    theta_w.name = "VFLXTHETA"
    
    qprime = ds.RV - ds.RV.mean()
    qw = ds.WC * qprime
    qw.name = 'VFLXQ'

    theta_v = ds.THETA * (1 + 0.61 * ds.RV - (ds.RCP + ds.RRP))
    theta_v_prime = theta_v - theta_v.mean()
    tvw = ds.WC * theta_v_prime
    tvw.name = 'VFLXTHETA_V'

    tke

    qw.mean(dim=('x','y')).to_netcdf(f'{outfile}', mode='a')
    theta_w.mean(dim=('x','y')).to_netcdf(f'{outfile}', mode='a')
    ww.mean(dim=('x','y')).to_netcdf(f'{outfile}', mode='a')
    tvw.mean(dim=('x','y')).to_netcdf(f'{outfile}', mode='a')
    tke.mean(dim=('x','y')).to_netcdf(f'{outfile}', mode='a')
