import xarray as xr
from glob import glob
import pyrams.xarray
from pyrams.data_tools import domain_mean_netcdf
import os

import argparse
parser = argparse.ArgumentParser()
parser.add_argument('path', type=str, help='Path to h5 files')
parser.add_argument('outfile', type=str, help='Path and name of Netcdf4 file to generate')
parser.add_argument('--parallel', action='store_true', help='Run in parallel with Dask')

args = vars(parser.parse_args())

fpath = args['path']
outfile = args['outfile']
parallel = args['parallel']
print(f"Reading files from {fpath}")
print(f"Writing to {outfile}")

user = os.environ['USER']
jobid = os.environ['SLURM_JOB_ID']
scratch = f'/scratch/{user}/{jobid}/'

tempout = scratch + 'out.nc'

if __name__ == '__main__':
    print(f"Making directory {scratch}")
    os.makedirs(scratch, exist_ok=True)
    if parallel:
        from dask.distributed import Client
        client=Client(local_directory=scratch)
        print("Running in parallel")
        p = True
    else:
        p = False

    flist = sorted(glob(fpath + '/*.h5'))
    print("Opening dataset")
    ds = xr.open_mfdataset(flist, combine='nested', concat_dim='time', parallel=p)
    ds = ds.rams.fix_dims(flist=flist, dx=62.5, dz=6.25)

    print("Writing to disk")
    domain_mean_netcdf(ds, tempout)

    print(f"Moving from {tempout} to {outfile}")
    os.system(f"mv {tempout} {outfile}")
    os.system(f"rm -rf {scratch}")